AppColor class
Constructors
- AppColor()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- blackBg → const Color
- colorPrimary → const Color
- colorPrimaryDark → const Color
- greenGrey → const Color
- inputFocusColor → const Color
- lightnewColor → const Color
- lightPrimary → const Color
- newColor → const Color
- newLightColor → const Color
- noticeColor → const Color
- offLineColor → const Color
- onLineColor → const Color
- secondaryPrimary → const Color
- splashColor → const Color
- splashColorPrimary → const Color
- verylightPrimary → const Color
- warningColor → const Color